.. _annotation_ref:

Time series annotation
======================

The :mod:`sktime.annotation` module contains algorithms and composition tools
for time series annotation (for example, anomaly or outlier detection).

.. automodule:: sktime.annotation
   :no-members:
   :no-inherited-members:


Adapters
--------

.. currentmodule:: sktime.annotation.adapters

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    PyODAnnotator
